@@ -23,6 +23,12 @@ class Option(object):
 
         self.parse(name, description)
 
+    def __str__(self):
+        return self.key
+
+    def __repr__(self):
+        return '<Option "%s">' % str(self)
+
     def parse(self, name, description):
         """
         Parse option name.
@@ -129,10 +135,12 @@ class Command(object):
     """
     The command interface.
 
-    :param name: program name
+    :param name: name of the program
     :param description: description of the program
     :param version: version of the program
     :param usage: usage of the program
+    :param title: title of the program
+    :param func: command function to be invoked
 
     Create a :class:`Command` instance in your cli file::
 
@@ -185,15 +193,16 @@ class Command(object):
     """
 
     def __init__(self, name, description=None, version=None, usage=None,
-                 title=None):
+                 title=None, func=None, help_footer=None):
         self._name = name
         self._description = description
         self._version = version
         self._usage = usage
         self._title = title
+        self._command_func = func
+        self._help_footer = help_footer
 
         self._parent = None
-        self._command_func = None
         self._option_list = []
         self._command_list = []
 
@@ -280,7 +289,7 @@ class Command(object):
         return self
 
     def _add_default_options(self):
-        def print_help():
+        def print_help():  # pragma: no cover
             self.print_help()
             return sys.exit(0)
 
@@ -291,7 +300,7 @@ class Command(object):
         )
 
         if self._version:
-            def print_version():
+            def print_version():  # pragma: no cover
                 self.print_version()
                 return sys.exit(0)
 
@@ -344,7 +353,7 @@ class Command(object):
                     self._argv = self._argv[1:]
 
             if not value:
-                raise RuntimeError('Missing value for: %s', option.name)
+                raise RuntimeError('Missing value for: %s' % option.name)
 
             self._results[option.key] = option.to_python(value)
             return True
@@ -391,10 +400,6 @@ class Command(object):
         # it is a function
         func = command
         args, varargs, keywords, defaults = inspect.getargspec(func)
-        if not args:
-            # a pure function
-            self._command_list.append(func)
-            return self
 
         if func.__doc__:
             doclines = func.__doc__.splitlines()
@@ -403,40 +408,47 @@ class Command(object):
         doclines = filter(lambda o: o.strip(), doclines)
         doclines = list(map(lambda o: o.strip(), doclines))
 
-        def find_description(arg):
-            text = ':param %s:' % arg
-            for line in doclines:
-                if line.startswith(text):
-                    return line.replace(text, '').strip()
-            return None
+        params = {}
+        options = {}
+
+        for line in doclines:
+            if line.startswith(':param '):
+                name, desc = line[7:].split(':', 1)
+                params[name.strip()] = desc.strip()
+            elif line.startswith(':option '):
+                name, desc = line[8:].split(':', 1)
+                options[name.strip()] = desc.strip()
 
         desc = None
         if doclines:
             desc = doclines[0]
 
-        cmd = Command(func.__name__, desc)
+        # use self.__class__ instead of Command for inherit
+        cmd = self.__class__(func.__name__, desc)
 
         defaults = defaults or []
         kwargs = dict(zip(*[reversed(i) for i in (args, defaults)]))
 
         for arg in args:
-            desc = find_description(arg)
+            desc = params.get(arg, None)
+            name = options.get(arg, None)
             if arg in kwargs:
                 value = kwargs[arg]
-
                 if value is True:
-                    option = Option('--no-%s' % arg, desc)
+                    name = name or '--no-%s' % arg
+                    option = Option(name, desc)
                 elif value is False:
-                    option = Option('-%s, --%s' % (arg[0], arg), desc)
+                    name = name or '-%s, --%s' % (arg[0], arg)
+                    option = Option(name, desc)
                 else:
-                    option = Option(
-                        '-%s, --%s [%s]' % (arg[0], arg, arg), desc
-                    )
+                    name = name or '-%s, --%s [%s]' % (arg[0], arg, arg)
+                    option = Option(name, desc)
                     option.default = value
 
                 cmd.option(option)
             else:
-                cmd.option('-%s, --%s <%s>' % (arg[0], arg, arg), desc)
+                name = name or '-%s, --%s <%s>' % (arg[0], arg, arg)
+                cmd.option(name, desc)
 
         cmd._command_func = func
         self._command_list.append(cmd)
@@ -456,6 +468,7 @@ class Command(object):
 
         self._argv = argv[1:]
         if not self._argv:
+            self.validate_options()
             if self._command_func:
                 self._command_func(**self._results)
             return self
@@ -469,9 +482,6 @@ class Command(object):
                     command._parent = self
                     return command.parse(self._argv)
 
-                if inspect.isfunction(command) and command.__name__ == cmd:
-                    return command()
-
         while self._argv:
             arg = self._argv[0]
             self._argv = self._argv[1:]
@@ -552,21 +562,20 @@ class Command(object):
             print('    %s %s' % (_pad(o.name, arglen), o.description or ''))
         print('')
 
-        if not self._command_list:
-            return self
+        if self._command_list:
+            self.print_title('  Commands:\n')
+            for cmd in self._command_list:
+                if isinstance(cmd, Command):
+                    name = _pad(cmd._name, arglen)
+                    desc = cmd._description or ''
+                    print('    %s %s' % (_pad(name, arglen), desc))
 
-        self.print_title('\n  Commands:\n')
-        for cmd in self._command_list:
-            if isinstance(cmd, Command):
-                name = _pad(cmd._name, arglen)
-                desc = cmd._description or ''
-                print('    %s %s' % (_pad(name, arglen), desc))
-            elif inspect.isfunction(cmd):
-                name = _pad(cmd.__name__, arglen)
-                desc = cmd.__doc__
-                print('    %s %s' % (_pad(name, arglen), desc))
+            print('')
+
+        if self._help_footer:
+            print(self._help_footer)
+            print('')
 
-        print('')
         return self
 
 
